@@ -2,7 +2,7 @@
 /*
  *  date_time.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 02 Sep 2008 01:46:00 JST
+ *  Last-modified: Sun 04 Jan 2009 17:48:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_DATE_TIME_H
@@ -269,7 +269,7 @@ namespace clx {
 		template <class CharT>
 		std::basic_string<CharT> to_string(const CharT* fmt) {
 			CharT tmp[1024];
-			size_t n = detail::time_to_string(tmp, sizeof(tmp), fmt, &date_);
+			size_t n = detail::time_to_string(tmp, sizeof(tmp) / sizeof(CharT), fmt, &date_);
 			if (n == 0) throw std::runtime_error("temporary buffer is overflow");
 			return std::basic_string<CharT>(tmp);
 		}
